LbClmmError

Enum LbClmmError 

pub enum LbClmmError {
Show 83 variants InvalidStartBinIndex = 6_000, InvalidBinId = 6_001, InvalidInput = 6_002, ExceededAmountSlippageTolerance = 6_003, ExceededBinSlippageTolerance = 6_004, CompositionFactorFlawed = 6_005, NonPresetBinStep = 6_006, ZeroLiquidity = 6_007, InvalidPosition = 6_008, BinArrayNotFound = 6_009, InvalidTokenMint = 6_010, InvalidAccountForSingleDeposit = 6_011, PairInsufficientLiquidity = 6_012, InvalidFeeOwner = 6_013, InvalidFeeWithdrawAmount = 6_014, InvalidAdmin = 6_015, IdenticalFeeOwner = 6_016, InvalidBps = 6_017, MathOverflow = 6_018, TypeCastFailed = 6_019, InvalidRewardIndex = 6_020, InvalidRewardDuration = 6_021, RewardInitialized = 6_022, RewardUninitialized = 6_023, IdenticalFunder = 6_024, RewardCampaignInProgress = 6_025, IdenticalRewardDuration = 6_026, InvalidBinArray = 6_027, NonContinuousBinArrays = 6_028, InvalidRewardVault = 6_029, NonEmptyPosition = 6_030, UnauthorizedAccess = 6_031, InvalidFeeParameter = 6_032, MissingOracle = 6_033, InsufficientSample = 6_034, InvalidLookupTimestamp = 6_035, BitmapExtensionAccountIsNotProvided = 6_036, CannotFindNonZeroLiquidityBinArrayId = 6_037, BinIdOutOfBound = 6_038, InsufficientOutAmount = 6_039, InvalidPositionWidth = 6_040, ExcessiveFeeUpdate = 6_041, PoolDisabled = 6_042, InvalidPoolType = 6_043, ExceedMaxWhitelist = 6_044, InvalidIndex = 6_045, RewardNotEnded = 6_046, MustWithdrawnIneligibleReward = 6_047, UnauthorizedAddress = 6_048, OperatorsAreTheSame = 6_049, WithdrawToWrongTokenAccount = 6_050, WrongRentReceiver = 6_051, AlreadyPassActivationPoint = 6_052, ExceedMaxSwappedAmount = 6_053, InvalidStrategyParameters = 6_054, LiquidityLocked = 6_055, BinRangeIsNotEmpty = 6_056, NotExactAmountOut = 6_057, InvalidActivationType = 6_058, InvalidActivationDuration = 6_059, MissingTokenAmountAsTokenLaunchProof = 6_060, InvalidQuoteToken = 6_061, InvalidBinStep = 6_062, InvalidBaseFee = 6_063, InvalidPreActivationDuration = 6_064, AlreadyPassPreActivationSwapPoint = 6_065, InvalidStatus = 6_066, ExceededMaxOracleLength = 6_067, InvalidMinimumLiquidity = 6_068, NotSupportMint = 6_069, UnsupportedMintExtension = 6_070, UnsupportNativeMintToken2022 = 6_071, UnmatchTokenMint = 6_072, UnsupportedTokenMint = 6_073, InsufficientRemainingAccounts = 6_074, InvalidRemainingAccountSlice = 6_075, DuplicatedRemainingAccountTypes = 6_076, MissingRemainingAccountForTransferHook = 6_077, NoTransferHookProgram = 6_078, ZeroFundedAmount = 6_079, InvalidSide = 6_080, InvalidResizeLength = 6_081, NotSupportAtTheMoment = 6_082,
}

Variants



InvalidStartBinIndex = 6_000

6000 - Invalid start bin index



InvalidBinId = 6_001

6001 - Invalid bin id



InvalidInput = 6_002

6002 - Invalid input data



ExceededAmountSlippageTolerance = 6_003

6003 - Exceeded amount slippage tolerance



ExceededBinSlippageTolerance = 6_004

6004 - Exceeded bin slippage tolerance



CompositionFactorFlawed = 6_005

6005 - Composition factor flawed



NonPresetBinStep = 6_006

6006 - Non preset bin step



ZeroLiquidity = 6_007

6007 - Zero liquidity



InvalidPosition = 6_008

6008 - Invalid position



BinArrayNotFound = 6_009

6009 - Bin array not found



InvalidTokenMint = 6_010

6010 - Invalid token mint



InvalidAccountForSingleDeposit = 6_011

6011 - Invalid account for single deposit



PairInsufficientLiquidity = 6_012

6012 - Pair insufficient liquidity



InvalidFeeOwner = 6_013

6013 - Invalid fee owner



InvalidFeeWithdrawAmount = 6_014

6014 - Invalid fee withdraw amount



InvalidAdmin = 6_015

6015 - Invalid admin



IdenticalFeeOwner = 6_016

6016 - Identical fee owner



InvalidBps = 6_017

6017 - Invalid basis point



MathOverflow = 6_018

6018 - Math operation overflow



TypeCastFailed = 6_019

6019 - Type cast error



InvalidRewardIndex = 6_020

6020 - Invalid reward index



InvalidRewardDuration = 6_021

6021 - Invalid reward duration



RewardInitialized = 6_022

6022 - Reward already initialized



RewardUninitialized = 6_023

6023 - Reward not initialized



IdenticalFunder = 6_024

6024 - Identical funder



RewardCampaignInProgress = 6_025

6025 - Reward campaign in progress



IdenticalRewardDuration = 6_026

6026 - Reward duration is the same



InvalidBinArray = 6_027

6027 - Invalid bin array



NonContinuousBinArrays = 6_028

6028 - Bin arrays must be continuous



InvalidRewardVault = 6_029

6029 - Invalid reward vault



NonEmptyPosition = 6_030

6030 - Position is not empty



UnauthorizedAccess = 6_031

6031 - Unauthorized access



InvalidFeeParameter = 6_032

6032 - Invalid fee parameter



MissingOracle = 6_033

6033 - Missing oracle account



InsufficientSample = 6_034

6034 - Insufficient observation sample



InvalidLookupTimestamp = 6_035

6035 - Invalid lookup timestamp



BitmapExtensionAccountIsNotProvided = 6_036

6036 - Bitmap extension account is not provided



CannotFindNonZeroLiquidityBinArrayId = 6_037

6037 - Cannot find non-zero liquidity binArrayId



BinIdOutOfBound = 6_038

6038 - Bin id out of bound



InsufficientOutAmount = 6_039

6039 - Insufficient amount in for minimum out



InvalidPositionWidth = 6_040

6040 - Invalid position width



ExcessiveFeeUpdate = 6_041

6041 - Excessive fee update



PoolDisabled = 6_042

6042 - Pool disabled



InvalidPoolType = 6_043

6043 - Invalid pool type



ExceedMaxWhitelist = 6_044

6044 - Whitelist for wallet is full



InvalidIndex = 6_045

6045 - Invalid index



RewardNotEnded = 6_046

6046 - Reward not ended



MustWithdrawnIneligibleReward = 6_047

6047 - Must withdraw ineligible reward



UnauthorizedAddress = 6_048

6048 - Unauthorized address



OperatorsAreTheSame = 6_049

6049 - Cannot update because operators are the same



WithdrawToWrongTokenAccount = 6_050

6050 - Withdraw to wrong token account



WrongRentReceiver = 6_051

6051 - Wrong rent receiver



AlreadyPassActivationPoint = 6_052

6052 - Already activated



ExceedMaxSwappedAmount = 6_053

6053 - Swapped amount is exceeded max swapped amount



InvalidStrategyParameters = 6_054

6054 - Invalid strategy parameters



LiquidityLocked = 6_055

6055 - Liquidity locked



BinRangeIsNotEmpty = 6_056

6056 - Bin range is not empty



NotExactAmountOut = 6_057

6057 - Amount out is not matched with exact amount out



InvalidActivationType = 6_058

6058 - Invalid activation type



InvalidActivationDuration = 6_059

6059 - Invalid activation duration



MissingTokenAmountAsTokenLaunchProof = 6_060

6060 - Missing token amount as token launch owner proof



InvalidQuoteToken = 6_061

6061 - Quote token must be SOL or USDC



InvalidBinStep = 6_062

6062 - Invalid bin step



InvalidBaseFee = 6_063

6063 - Invalid base fee



InvalidPreActivationDuration = 6_064

6064 - Invalid pre-activation duration



AlreadyPassPreActivationSwapPoint = 6_065

6065 - Already pass pre-activation swap point



InvalidStatus = 6_066

6066 - Invalid status



ExceededMaxOracleLength = 6_067

6067 - Exceed max oracle length



InvalidMinimumLiquidity = 6_068

6068 - Invalid minimum liquidity



NotSupportMint = 6_069

6069 - Not support token_2022 mint extension



UnsupportedMintExtension = 6_070

6070 - Unsupported mint extension



UnsupportNativeMintToken2022 = 6_071

6071 - Unsupported native mint token2022



UnmatchTokenMint = 6_072

6072 - Unmatch token mint



UnsupportedTokenMint = 6_073

6073 - Unsupported token mint



InsufficientRemainingAccounts = 6_074

6074 - Insufficient remaining accounts



InvalidRemainingAccountSlice = 6_075

6075 - Invalid remaining account slice



DuplicatedRemainingAccountTypes = 6_076

6076 - Duplicated remaining account types



MissingRemainingAccountForTransferHook = 6_077

6077 - Missing remaining account for transfer hook



NoTransferHookProgram = 6_078

6078 - Remaining account was passed for transfer hook but there’s no hook program



ZeroFundedAmount = 6_079

6079 - Zero funded amount



InvalidSide = 6_080

6080 - Invalid side



InvalidResizeLength = 6_081

6081 - Invalid resize length



NotSupportAtTheMoment = 6_082

6082 - Not support at the moment