pub struct InitializePositionByOperatorCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for InitializePositionByOperator via CPI.
Accounts:
[writable, signer]payer[signer]base[writable]position[]lb_pair[]owner[signer]operator[]operator_token_x[]owner_token_x[]system_program[]event_authority[]program
Implementations
Sourceimpl<'a, 'b> InitializePositionByOperatorCpiBuilder<'a, 'b>
impl<'a, 'b> InitializePositionByOperatorCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn payer(&mut self, payer: &'b AccountInfo<'a>) -> &mut Self
pub fn base(&mut self, base: &'b AccountInfo<'a>) -> &mut Self
pub fn position(&mut self, position: &'b AccountInfo<'a>) -> &mut Self
pub fn lb_pair(&mut self, lb_pair: &'b AccountInfo<'a>) -> &mut Self
pub fn owner(&mut self, owner: &'b AccountInfo<'a>) -> &mut Self
Sourcepub fn operator(&mut self, operator: &'b AccountInfo<'a>) -> &mut Self
pub fn operator(&mut self, operator: &'b AccountInfo<'a>) -> &mut Self
operator
pub fn operator_token_x( &mut self, operator_token_x: &'b AccountInfo<'a>, ) -> &mut Self
pub fn owner_token_x(&mut self, owner_token_x: &'b AccountInfo<'a>) -> &mut Self
pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn program(&mut self, program: &'b AccountInfo<'a>) -> &mut Self
pub fn lower_bin_id(&mut self, lower_bin_id: i32) -> &mut Self
pub fn width(&mut self, width: i32) -> &mut Self
pub fn fee_owner(&mut self, fee_owner: Pubkey) -> &mut Self
pub fn lock_release_point(&mut self, lock_release_point: u64) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult